@@ -2,8 +2,8 @@ from ..utils import *
 from abstract_apis import *
 
 async def asyncCallRequest(endpoint,*args,**kwargs):
-  endpoint = make_endpoint(endpoint)
-  return await asyncPostRequest(getCallUrl(),kwargs,endpoint=endpoint)
+  url = getEndpointUrl(endpoint)
+  return await asyncPostRequest(url,kwargs)
 
 def callSolcatcherRpc(endpoint=None,**kwargs):
   url = getEndpointUrl(endpoint)
