@@ -48,18 +48,9 @@ def getTokenAccountByOwner(account,mint):
   return solcatcherPostRequest('tokenaccountsbyowner',**{"account":account,"mint":mint})
 def getPoolInfo(address=None,signature=None,txData=None):
   return solcatcherPostRequest('getpoolinfo',**{"address":address,"signature":signature,"txData":txData})
+def getGenesisSignature(address, limit=1000, before=None, after=None, finalized=True):
+  return solcatcherPostRequest('getgenesistransaction',address=address, limit=limit, before=before, after=after, finalized=finalized)
+def getTxnTypeFromMint(address):
+  return solcatcherPostRequest('gettxntypefrommint',address=address)
 def getLatestBlockHash():
-  return solcatcherPostRequest("getlatestblockhash")
-def get_genesis_signature(account):
-  limit=1000
-  before=None
-  account = str(account)
-  SignaturesFromAddress = getSignaturesForAddress(address=account, limit=limit, before=before)
-  before = SignaturesFromAddress[-1].get('signature')
-  
-  while True:
-    SignaturesFromAddress = getSignaturesForAddress(address=account, limit=limit, before=before)
-    if SignaturesFromAddress:
-      before = SignaturesFromAddress[-1].get('signature')
-    if len(SignaturesFromAddress)<limit:
-      return before
+  return solcatcherPostRequest('getlatestblockhash')
